import { __rest } from "tslib";
import { jsx as _jsx, jsxs as _jsxs } from "@emotion/react/jsx-runtime";
import React from "react";
import EditorContext from "./EditorContext";
import { Link, useNavigate } from "react-router-dom";
import { motion } from "framer-motion";
import { Box, useMediaQuery } from "@chakra-ui/react";
import { directionMotion, duration } from "./directionMotion";
import { RuntimeContext } from "@qorebase/app-component";
import NavigationList from "./NavigationList";
import InAppInstalPromotion from "./InAppInstalPromotion";
export const MotionBox = motion(Box);
const exitBackDirection = {
    slideRight: "slideLeft",
    slideLeft: "slideRight",
    slideUp: "slideDown",
    slideDown: "slideUp",
    scale: "none",
    fade: "none",
};
const ComposerContext = React.createContext({
    modalPageHistoryLength: 0,
    direction: "none",
    exitDirection: "none",
    setDirection: () => null,
    setExitDirection: () => null,
    forward: () => null,
    back: () => null,
    setModalPageHistoryLength: () => null,
});
export const Composer = ({ children }) => {
    const [direction, setDirection] = React.useState("none");
    const [exitDirection, setExitDirection] = React.useState("none");
    const [modalPageHistoryLength, setModalPageHistoryLength] = React.useState(0);
    const navigate = useNavigate();
    const forward = React.useCallback((url, opts) => {
        var _a;
        setExitDirection(((_a = opts === null || opts === void 0 ? void 0 : opts.state) === null || _a === void 0 ? void 0 : _a.direction) || "none");
        if (opts === null || opts === void 0 ? void 0 : opts.modalPage)
            setModalPageHistoryLength((state) => state + 1);
        (opts === null || opts === void 0 ? void 0 : opts.state) ? navigate(url, { state: opts.state }) : navigate(url);
    }, [navigate]);
    const back = React.useCallback((opts) => {
        setExitDirection(exitBackDirection[direction]);
        if (opts === null || opts === void 0 ? void 0 : opts.modalPage) {
            setModalPageHistoryLength((state) => (state === 0 ? 0 : state - 1));
        }
        if (history.length === 1) {
            (opts === null || opts === void 0 ? void 0 : opts.state) ? navigate("/", { state: opts.state }) : navigate("/");
        }
        else {
            navigate(-1);
        }
    }, [navigate, direction]);
    return (_jsx(ComposerContext.Provider, Object.assign({ value: {
            direction,
            exitDirection,
            setDirection,
            setExitDirection,
            forward,
            back,
            modalPageHistoryLength,
            setModalPageHistoryLength,
        } }, { children: children })));
};
export const useComposer = () => React.useContext(ComposerContext);
export const TransitionLink = (_a) => {
    var { children, direction } = _a, props = __rest(_a, ["children", "direction"]);
    return _jsx(Link, Object.assign({}, props, { children: children }));
};
export const Scene = ({ children }) => {
    var _a, _b, _c;
    const { direction, exitDirection, setDirection } = useComposer();
    React.useEffect(() => {
        const timeout = setTimeout(() => setDirection(exitDirection), duration * 1000 - 50);
        return () => clearTimeout(timeout);
    }, [exitDirection]);
    const currentPage = RuntimeContext.useSelectState((state) => state.app.maps.page[state.control.page]);
    const hasBottomNav = ["navigation", "menu"].includes(currentPage === null || currentPage === void 0 ? void 0 : currentPage.type);
    const [smallScreen, mediumScreen] = useMediaQuery([
        "(max-width: 480px)",
        "(max-width: 48em)",
    ]);
    const screen = EditorContext.useSelectState((state) => state.screen);
    const navs = RuntimeContext.useSelectState((state) => state.app.navbar.bottom);
    return (_jsxs(Box, Object.assign({ w: "full", h: "full", bg: "bg.900" }, { children: [mediumScreen ? (_jsxs(MotionBox, Object.assign({ initial: (_a = directionMotion[direction]) === null || _a === void 0 ? void 0 : _a.initial, animate: (_b = directionMotion[direction]) === null || _b === void 0 ? void 0 : _b.animate, exit: (_c = directionMotion[exitDirection]) === null || _c === void 0 ? void 0 : _c.exit, position: "absolute", inset: 0, bgColor: "qore.primary", overflow: "unset", height: "full" }, { children: [_jsx(MotionBox, Object.assign({ position: "absolute", 
                        // inset={0}
                        top: 0, right: 0, left: 0, bottom: "55px", overflow: "unset", animate: {
                            transition: {
                                duration,
                                ease: "easeOut",
                            },
                            bottom: (smallScreen || screen === "small") &&
                                (currentPage === null || currentPage === void 0 ? void 0 : currentPage.navbar.bottom.show) &&
                                (navs.content.length > 0 || hasBottomNav)
                                ? "55px"
                                : 0,
                        } }, { children: children })), (currentPage === null || currentPage === void 0 ? void 0 : currentPage.navbar.bottom.show) && navs.content.length > 0 && (_jsx(NavigationList, {})), _jsx(InAppInstalPromotion, {})] }), "motion-box")) : (_jsx(Box, Object.assign({ inset: 0, bgColor: "qore.primary", overflow: "unset", height: "full" }, { children: children }), "no-motion")), _jsx(InAppInstalPromotion, {})] })));
};
//# sourceMappingURL=Composer.js.map