import { jsx as _jsx, jsxs as _jsxs } from "@emotion/react/jsx-runtime";
import React from "react";
import { Box, Icon, IconButton, Modal, ModalBody, ModalCloseButton, ModalContent, ModalHeader, ModalOverlay, useDisclosure, useMediaQuery, } from "@chakra-ui/react";
import { RuntimeContext } from "@qorebase/app-component";
import { Page } from "./ActivePage";
import { useModalPageSource } from "./hooks/useSource";
import { useLocation } from "react-router-dom";
import * as queryString from "./utils/query-string";
import { useComposer } from "./Composer";
import iconsList from "./components/iconsList";
import { omit } from "./utils/omit";
import { RuntimeInputProvider } from "./RuntimeInput";
export default function ModalPage() {
    const [mobileView] = useMediaQuery("(max-width: 767px)");
    const location = useLocation();
    const compose = useComposer();
    const query = React.useMemo(() => queryString.parse(location.search), [location.search]);
    const stateLocation = useLocation().state;
    const disclosure = useDisclosure();
    React.useEffect(() => {
        query.modalPage && disclosure.onOpen();
    }, [query.modalPage]);
    const page = RuntimeContext.useSelectState((runtime) => runtime.app.maps.page[query.modalPage || ""]);
    const source = useModalPageSource();
    const handleClose = React.useCallback(() => {
        disclosure.onClose();
        const currentQuery = omit(["modalPage", "modalRowId", "modalH"], query);
        const newQuery = queryString.stringify(currentQuery);
        compose.setModalPageHistoryLength(0);
        setTimeout(() => compose.forward(`${location.pathname}?${newQuery}`), 300);
    }, [location.pathname, query]);
    const handleBackButton = React.useCallback(() => compose.back({ modalPage: true }), [compose]);
    if (!page)
        return null;
    return (_jsxs(Modal, Object.assign({ isOpen: disclosure.isOpen, onClose: handleClose, onOverlayClick: handleClose, scrollBehavior: "inside", trapFocus: false, size: "xl", isCentered: true, motionPreset: (stateLocation === null || stateLocation === void 0 ? void 0 : stateLocation.direction) || "scale" }, { children: [_jsx(ModalOverlay, {}), _jsxs(ModalContent, Object.assign({ position: mobileView ? "absolute" : undefined, bottom: mobileView && 0, margin: mobileView && 0, borderBottomRadius: mobileView && 0, height: (stateLocation === null || stateLocation === void 0 ? void 0 : stateLocation.modalH) || "75%", maxHeight: mobileView && "100%" }, { children: [_jsx(ModalCloseButton, {}), _jsxs(ModalHeader, Object.assign({ textAlign: mobileView ? "center" : undefined }, { children: [compose.modalPageHistoryLength > 0 && (_jsx(IconButton, { position: "absolute", left: 0, variant: "unstyled", "aria-label": "modal-back", icon: _jsx(Icon, { as: iconsList["ArrowLeft"] }), onClick: handleBackButton })), page.title] })), _jsx(ModalBody, Object.assign({ padding: mobileView && 0 }, { children: _jsx(Box, Object.assign({ position: "relative", height: "100%" }, { children: _jsx(Box, Object.assign({ position: "absolute", top: "0", left: "0", right: "0", bottom: "0" }, { children: disclosure.isOpen && (_jsx(RuntimeInputProvider, { children: _jsx(Page, { page: page, source: source, excludeNavigation: true }) })) })) })) }))] }))] })));
}
//# sourceMappingURL=ModalPage.js.map