import { __awaiter, __rest } from "tslib";
import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "@emotion/react/jsx-runtime";
import React from "react";
import { Avatar, Box, Flex, Text, Drawer, DrawerBody, DrawerContent, DrawerHeader, DrawerOverlay, Icon, useDisclosure, HStack, Stack, Spacer, Modal, ModalOverlay, ModalContent, ModalBody, Center, } from "@chakra-ui/react";
import { Link, useLocation, useParams } from "react-router-dom";
import { css } from "@emotion/react";
import { RuntimeContext } from "../RuntimeContext";
import { ArrowBackIcon, HamburgerIcon } from "@chakra-ui/icons";
import useTemplate from "../hooks/useTemplate";
import { useActionTrigger } from "../hooks/useActionTrigger";
import { useSource } from "../hooks/useSource";
import iconsList from "../components/iconsList";
import { useComposer } from "../Composer";
import { Delete, DotMore } from "@feedloop/icon";
import { useNavigations } from "../hooks/navigations";
import Scrollbars from "rc-scrollbars";
import { getThemes } from "../registeredThemes";
import Tree, { mutateTree } from "@atlaskit/tree";
const NavigationList = ({ navigations, params, composer }) => {
    return (_jsx(_Fragment, { children: navigations.map((menu) => (_jsx(Box, Object.assign({ py: "1", px: "4" }, { children: _jsx(Link, Object.assign({ to: `/page/${menu.id}`, onClick: () => composer.setExitDirection("none") }, { children: _jsxs(HStack, Object.assign({ cursor: "pointer", spacing: 2, px: 4, py: 2, bg: params.page === menu.id ? "qore.primary" : "white", transition: "background 200ms ease-out", _hover: {
                        bg: params.page === menu.id ? "qore.primary" : "bg.900",
                    }, rounded: "md", textDecoration: "none", _focusVisible: {
                        outline: "none",
                    } }, { children: [_jsx(Icon, { as: iconsList[menu.icon], cursor: "pointer", color: params.page === menu.id ? "white" : "text.900" }), _jsx(Text, Object.assign({ color: params.page === menu.id ? "white" : "text.900" }, { children: menu.title }))] }), menu.id + "stack") })) }), menu.id))) }));
};
const RenderItem = ({ item, navigations, provided, onCollapse, onExpand, params, composer, }) => {
    const isParent = React.useMemo(() => navigations.items[item.id].children.length > 0, [item, navigations]);
    return (_jsxs(Flex, Object.assign({ justifyContent: "space-between", alignItems: "center", bg: "white", borderRadius: "md", py: "2", px: "2", bgColor: params.page === item.data.page ? "qore.primary" : "", transition: "opacity 200ms ease-out" }, provided.draggableProps, { children: [_jsx(Link, Object.assign({ to: (isParent && item.data.linked) || !isParent
                    ? `/page/${item.data.page}`
                    : "", onClick: () => composer.setExitDirection("none") }, { children: _jsxs(Center, Object.assign({ gap: "2", pl: "4", w: "full", cursor: "pointer", justifyContent: "left" }, { children: [_jsx(Icon, { color: params.page === item.data.page ? "white" : "text.900", as: iconsList[item.data.icon] }), _jsx(Text, Object.assign({ color: params.page === item.data.page ? "white" : "text.900" }, { children: item.data.label }))] })) })), _jsx(Center, { children: item.children && item.children.length > 0 && (_jsx(Icon, { boxSize: 5, color: params.page === item.data.page ? "white" : "text.900", as: iconsList["ChevronDown"], onClick: () => item.isExpanded ? onCollapse(item.id) : onExpand(item.id), transition: "all 200ms ease-out", transform: `rotate(${item.isExpanded ? 0 : -90}deg)`, cursor: "pointer" })) })] })));
};
function usePromiseCallback(fn) {
    const [state, setState] = React.useState({ status: "idle" });
    const exec = React.useCallback((...args) => __awaiter(this, void 0, void 0, function* () {
        setState({ status: "firing", error: undefined });
        try {
            const resp = yield fn(...args);
            setState({ status: "fired" });
            return resp;
        }
        catch (error) {
            setState({ status: "fired", error });
            throw error;
        }
    }), [fn]);
    return Object.assign({ exec }, state);
}
export const PageHeadingsMap = {
    display: (props) => {
        var _a, _b, _c, _d, _e, _f;
        const title = useTemplate(props.page.properties.values.title);
        const source = useSource();
        const stateLocation = useLocation().state;
        const runtimeActions = RuntimeContext.useActions();
        const appName = RuntimeContext.useSelectState((state) => state.app.name);
        const appIcon = RuntimeContext.useSelectState((state) => state.app.icon);
        const params = useParams();
        const action = useActionTrigger((_a = props.page) === null || _a === void 0 ? void 0 : _a.properties.values.action, props.row, source);
        const { isOpen, onOpen, onClose } = useDisclosure();
        const isAction = ((_b = props.page) === null || _b === void 0 ? void 0 : _b.properties.values.headerStyle) === "default";
        const { menus } = useNavigations();
        const isInitialPage = ((_c = props.page) === null || _c === void 0 ? void 0 : _c.type) === "navigation" || ((_d = props.page) === null || _d === void 0 ? void 0 : _d.type) === "menu";
        const collapsible = RuntimeContext.useSelectState((state) => state.app.navbar.sidetop.collapsible);
        const navigations = RuntimeContext.useSelectState((state) => state.app.navbar.sidetop.content);
        const onExpand = React.useCallback((itemId) => {
            const newTree = mutateTree(navigations, itemId, { isExpanded: true });
            runtimeActions.swapSidetopNavContent(newTree);
        }, [runtimeActions, navigations]);
        const onCollapse = React.useCallback((itemId) => {
            const newTree = mutateTree(navigations, itemId, { isExpanded: false });
            runtimeActions.swapSidetopNavContent(newTree);
        }, [runtimeActions, navigations]);
        const composer = useComposer();
        return (_jsxs(_Fragment, { children: [_jsxs(Flex, Object.assign({ alignItems: "center", h: "57px", padding: "16px", borderBottom: "1px solid", borderColor: "bg.900", bg: "surface.900" }, { children: [((isInitialPage && menus.length > 0) ||
                            navigations.items.root.children.length > 0) && (_jsx(Box, Object.assign({ display: {
                                base: props.page.navbar.drawer.show ? "initial" : "none",
                                md: collapsible ? "initial" : "none",
                            }, mr: "16px" }, { children: _jsx(HamburgerIcon, { height: "57px", boxSize: 7, onClick: onOpen, cursor: "pointer" }) }))), (stateLocation === null || stateLocation === void 0 ? void 0 : stateLocation.allowBackNav) && !isInitialPage && (_jsx(Box, { children: _jsx(ArrowBackIcon, { height: "57px", boxSize: 7, marginRight: "16px", onClick: props.onAbort, cursor: "pointer" }) })), _jsx(Text, Object.assign({ fontWeight: "bold", fontSize: "lg", noOfLines: 1, pr: 4, color: "text.900" }, { children: title })), _jsx(Spacer, {}), isAction && ((_e = props.page) === null || _e === void 0 ? void 0 : _e.properties.values.icon) !== "none" && (_jsx(Box, Object.assign({ cursor: "pointer" }, { children: _jsx(Icon, { as: iconsList[(_f = props.page) === null || _f === void 0 ? void 0 : _f.properties.values.icon], boxSize: 7, onClick: action.handleClick }) })))] })), _jsxs(Drawer, Object.assign({ placement: "left", onClose: onClose, isOpen: isOpen }, { children: [_jsx(DrawerOverlay, {}), _jsxs(DrawerContent, Object.assign({ p: 0, bg: "surface.800" }, { children: [_jsx(DrawerHeader, Object.assign({ borderBottom: "1px solid", borderColor: "bg.800" }, { children: _jsxs(Flex, Object.assign({ alignItems: "center", gap: "2" }, { children: [_jsx(Avatar, { size: "md", name: appName, src: appIcon, bg: "bg.900" }), _jsx(Text, { children: appName || "Menu" })] })) })), _jsxs(DrawerBody, Object.assign({ m: 0, p: 0 }, { children: [_jsxs(Stack, Object.assign({ direction: "column", spacing: 0, py: 2, display: {
                                                base: "none",
                                                md: navigations.items.root.children.length > 0
                                                    ? "initial"
                                                    : "none",
                                            } }, { children: [_jsx(Text, Object.assign({ px: 4, pt: 2, fontSize: "sm", fontWeight: "semibold", color: "text.700" }, { children: "General" })), _jsx(Flex, Object.assign({ direction: "column", borderRadius: "md", py: navigations.items.root.children.length > 0 ? 2 : 0, px: "4" }, { children: _jsx(Tree, { tree: navigations, renderItem: (e) => (_jsx(RenderItem, { item: e.item, navigations: navigations, provided: e.provided, onCollapse: onCollapse, onExpand: onExpand, params: params, composer: composer })), offsetPerLevel: 20, isNestingEnabled: true }) }))] })), _jsxs(Stack, Object.assign({ direction: "column", spacing: 0 }, { children: [_jsx(Text, Object.assign({ px: 4, pt: 2, color: "text.700", fontSize: "sm", fontWeight: "semibold" }, { children: "All Menus" })), _jsx(NavigationList, { navigations: menus, params: params, composer: composer })] }))] }))] }))] }))] }));
    },
    form: (props) => {
        var _a, _b;
        const title = useTemplate(props.page.properties.values.title);
        const stateLocation = useLocation().state;
        const { isOpen, onOpen, onClose } = useDisclosure();
        const { exec, status } = usePromiseCallback(props.onDeleteRow);
        const menuRef = React.useRef(null);
        return (_jsxs(Flex, Object.assign({ alignItems: "center", h: "57px", padding: "16px", borderBottom: "1px solid", borderColor: "bg.900", bg: "surface.900" }, { children: [(stateLocation === null || stateLocation === void 0 ? void 0 : stateLocation.allowBackNav) && (_jsx(Box, { children: _jsx(ArrowBackIcon, { height: "57px", boxSize: 6, marginRight: "16px", onClick: props.onAbort }) })), _jsx(Box, Object.assign({ flex: 1 }, { children: _jsx(Text, Object.assign({ fontWeight: "bold", fontSize: "lg", noOfLines: 1, pr: 4, color: "text.900" }, { children: title })) })), props.page.id === "register" ||
                    props.row.id === "none" ||
                    !props.page.properties.deletableForm ? null : (_jsxs(Box, { children: [_jsx(Icon, { cursor: "pointer", height: "57px", boxSize: 7, as: DotMore, onClick: (e) => {
                                const rect = e.currentTarget.getClientRects();
                                menuRef.current = rect;
                                onOpen();
                            } }), _jsxs(Modal, Object.assign({ motionPreset: "slideInBottom", trapFocus: false, scrollBehavior: "inside", isOpen: isOpen, onClose: onClose }, { children: [_jsx(ModalOverlay, { display: { base: "initial", md: "none" } }), _jsx(ModalContent, Object.assign({ w: { base: "100%", md: "auto" }, position: "absolute", top: { base: "unset", md: ((_a = menuRef.current) === null || _a === void 0 ? void 0 : _a[0].top) - 16 }, left: { base: "unset", md: ((_b = menuRef.current) === null || _b === void 0 ? void 0 : _b[0].left) - 60 }, bottom: { base: 0, md: "unset" }, padding: 0, marginBottom: 0, borderTopRadius: { base: "20px", md: "5px" }, borderBottomRadius: { base: "0px", md: "5px" } }, { children: _jsx(ModalBody, Object.assign({ css: css `
                    &::-webkit-scrollbar {
                      display: none;
                    }
                  `, pb: { base: "20px" }, mt: { base: "10px", md: 0 } }, { children: _jsxs(HStack, Object.assign({ p: "10px", mx: "-20px", mb: "-10px", _hover: { backgroundColor: "gray.100" }, cursor: "pointer", onClick: exec }, { children: [_jsx(Icon, { cursor: "pointer", fontSize: "20px", color: "#DE220B", as: Delete }), _jsx(Text, Object.assign({ fontSize: "16px", color: "#DE220B" }, { children: status === "firing" ? "Deleting.." : "Delete" }))] })) })) }))] }))] }))] })));
    },
};
const SidebarLayout = ({ children, page }) => {
    var _a;
    const appName = RuntimeContext.useSelectState((state) => state.app.name);
    const appIcon = RuntimeContext.useSelectState((state) => state.app.icon);
    const runtimeActions = RuntimeContext.useActions();
    const params = useParams();
    const composer = useComposer();
    const appTheme = RuntimeContext.useSelectState((state) => state.app.theme);
    const theme = (_a = getThemes().find((theme) => theme.id === appTheme.id)) === null || _a === void 0 ? void 0 : _a.theme;
    const renderThumb = React.useCallback((_a) => {
        var { style } = _a, props = __rest(_a, ["style"]);
        return (_jsx("div", Object.assign({ style: Object.assign(Object.assign({}, style), { backgroundColor: theme.colors.text["900"] }) }, props)));
    }, [theme]);
    const collapsible = RuntimeContext.useSelectState((state) => state.app.navbar.sidetop.collapsible);
    const { menus } = useNavigations();
    const navigations = RuntimeContext.useSelectState((state) => state.app.navbar.sidetop.content);
    const onExpand = React.useCallback((itemId) => {
        const newTree = mutateTree(navigations, itemId, { isExpanded: true });
        runtimeActions.swapSidetopNavContent(newTree);
    }, [runtimeActions, navigations]);
    const onCollapse = React.useCallback((itemId) => {
        const newTree = mutateTree(navigations, itemId, { isExpanded: false });
        runtimeActions.swapSidetopNavContent(newTree);
    }, [runtimeActions, navigations]);
    return (_jsxs(Box, Object.assign({ textColor: "text.900" }, { children: [_jsx(Box, Object.assign({ display: {
                    base: "none",
                    md: page.navbar.sidetop.show ? "initial" : "none",
                }, overflowY: "hidden", position: "absolute", height: "100%", maxWidth: { md: "30%", lg: "250px" }, top: "0", left: "0", right: "0", bg: "surface.800", borderRight: "1px solid", borderColor: "bg.900" }, { children: _jsx(Scrollbars, Object.assign({ renderThumbVertical: renderThumb, autoHide: true }, { children: _jsx(Flex, Object.assign({ alignItems: "center", h: "56px", bg: "qore.primary" }, { children: _jsxs(Box, Object.assign({ display: { base: "none", md: "initial" }, w: "100%", h: "100%", minH: "100%" }, { children: [_jsx(Box, Object.assign({ bg: "surface.900" }, { children: _jsxs(Flex, Object.assign({ alignItems: "center", h: "56px", padding: "16px", gap: "2" }, { children: [_jsx(Avatar, { size: "md", name: appName, src: appIcon, loading: "eager", bg: "bg.900", ignoreFallback: true }), _jsx(Text, Object.assign({ fontWeight: "bold", fontSize: "lg", noOfLines: 1, pr: 4, color: "text.900" }, { children: appName || "Menu" }))] })) })), _jsxs(Box, { children: [_jsxs(Stack, Object.assign({ direction: "column", spacing: 0, py: 2, display: navigations.items.root.children.length > 0
                                                ? "initial"
                                                : "none" }, { children: [_jsx(Text, Object.assign({ px: 4, pt: 2, fontSize: "sm", fontWeight: "semibold", color: "text.700" }, { children: "General" })), _jsx(Flex, Object.assign({ direction: "column", borderRadius: "md", py: navigations.items.root.children.length > 0 ? 2 : 0, px: "4" }, { children: _jsx(Tree, { tree: navigations, renderItem: (e) => (_jsx(RenderItem, { item: e.item, navigations: navigations, provided: e.provided, onCollapse: onCollapse, onExpand: onExpand, params: params, composer: composer })), offsetPerLevel: 20, isNestingEnabled: true }) }))] })), _jsxs(Stack, Object.assign({ direction: "column", spacing: 0, display: menus.length > 0 ? "initial" : "none", bg: "qore.primary" }, { children: [_jsx(Text, Object.assign({ px: 4, pt: 2, color: "text.700", fontSize: "sm", fontWeight: "semibold" }, { children: "All Menus" })), _jsx(NavigationList, { navigations: menus, params: params, composer: composer })] }))] })] })) })) })) })), _jsx(Box, Object.assign({ position: "absolute", left: {
                    base: 0,
                    md: !page.navbar.sidetop.show ? 0 : collapsible ? 0 : "30%",
                    lg: !page.navbar.sidetop.show ? 0 : collapsible ? 0 : "250px",
                }, right: "0", top: "0", bottom: "0", overflow: "hidden" }, { children: children }))] })));
};
export default SidebarLayout;
//# sourceMappingURL=SidebarLayout.js.map