import { jsx as _jsx, jsxs as _jsxs } from "@emotion/react/jsx-runtime";
import { Box } from "@chakra-ui/react";
import * as queryString from "./utils/query-string";
import { Navigate, Route, Routes, useLocation } from "react-router-dom";
import UserLogin from "./components/UserLogin";
import ActivePageContainer from "./ActivePageContainer";
import qore from "./hooks/qore";
import { VariablesProvider, RuntimeContext } from "@qorebase/app-component";
import { AnimatePresence } from "framer-motion";
import { Scene } from "./Composer";
import React from "react";
import produce from "immer";
import { ToastNotificationContextProvider } from "./ToastNotification";
import { QRScannerActionContextProvider } from "./QRScanner.action";
import { RuntimeInputProvider } from "./RuntimeInput";
export default function RuntimeContents() {
    const config = RuntimeContext.useSelectState((state) => state.app.config);
    const access_token = localStorage.getItem(`${config.projectID}_user_token`);
    const redirectPage = RuntimeContext.useSelectState((state) => {
        var _a, _b;
        return access_token
            ? (_a = state.app.config.initialPage) === null || _a === void 0 ? void 0 : _a.loggedInPage
            : (_b = state.app.config.initialPage) === null || _b === void 0 ? void 0 : _b.entryPage;
    });
    const pagesMap = RuntimeContext.useSelectState((state) => state.app.maps.page);
    const location = useLocation();
    const client = qore.useClient();
    const { user: originalUser } = qore.useCurrentUser();
    const user = React.useMemo(() => originalUser &&
        Object.fromEntries(Object.entries(originalUser).map(([key, val]) => [
            key,
            val && typeof val === "object" && "filename" in val
                ? `${client.project.config.endpoint}/v1/files/public/users/${originalUser.id}/${key}/${
                // @ts-ignore
                val.filename}`
                : val,
        ])), [originalUser, client.project.config.endpoint]);
    const [state, setState] = React.useState({ location: "0,0" });
    const userVariables = React.useMemo(() => {
        if (!user)
            return {};
        const userVar = {
            current_location: state.location,
        };
        return Object.fromEntries(Object.entries(user).map(([key, value]) => [
            `user.${key}`,
            key === "role" ? (value === null || value === void 0 ? void 0 : value.name) || value : value,
        ], userVar));
    }, [user, state.location, location.search]);
    const firstPage = React.useMemo(() => Object.values(pagesMap).filter((page) => page.type !== "system")[0], [pagesMap]);
    const variables = React.useMemo(() => {
        const parsed = queryString.parse(location.search);
        const rowId = (parsed === null || parsed === void 0 ? void 0 : parsed.rowId) || "";
        const modalRowId = (parsed === null || parsed === void 0 ? void 0 : parsed.modalRowId) || "";
        return Object.assign(Object.assign({}, userVariables), { rowId, modalRowId });
    }, [userVariables, location.search]);
    React.useEffect(function getLocation() {
        const watchId = navigator.geolocation
            ? navigator.geolocation.watchPosition((position) => {
                setState((state) => produce(state, (draft) => {
                    draft.location = `${position.coords.latitude},${position.coords.longitude}`;
                }));
            })
            : null;
        return () => {
            var _a;
            (_a = navigator.geolocation) === null || _a === void 0 ? void 0 : _a.clearWatch(watchId);
        };
    }, []);
    const firstPageNavigate = React.useMemo(() => (pagesMap[redirectPage] ? redirectPage : firstPage === null || firstPage === void 0 ? void 0 : firstPage.id), [pagesMap, firstPage, redirectPage]);
    return (_jsx(ToastNotificationContextProvider, { children: _jsx(QRScannerActionContextProvider, { children: _jsx(AnimatePresence, Object.assign({ initial: false, mode: "wait" }, { children: _jsxs(Routes, Object.assign({ location: location }, { children: [(redirectPage || firstPage) && (_jsx(Route, { path: "/", element: _jsx(Scene, { children: _jsx(Navigate, { to: `/page/${firstPageNavigate}` }) }) })), _jsx(Route, { path: "/page/:page", element: _jsx(Box, Object.assign({ position: "absolute", top: 0, left: 0, right: 0, bottom: 0, overflow: "unset" }, { children: _jsx(VariablesProvider, Object.assign({ values: variables }, { children: _jsx(RuntimeInputProvider, { children: _jsx(ActivePageContainer, {}) }) })) })) }), _jsx(Route, { path: "/login", element: _jsx(Scene, { children: _jsx(UserLogin, {}) }) })] }), location.pathname) })) }) }));
}
//# sourceMappingURL=RuntimeContents.js.map