import { __awaiter } from "tslib";
import { jsx as _jsx, jsxs as _jsxs } from "@emotion/react/jsx-runtime";
import React from "react";
import { QoreClient } from "@qorebase/client";
import createQoreHooks from "@qorebase/react";
const qoreHooks = createQoreHooks(new QoreClient({
    endpoint: "",
}));
const defaultUser = { status: "idle", error: null, user: null };
export const UserContext = React.createContext([defaultUser, () => { }]);
const UserFetcher = () => {
    const client = qore.useClient();
    const user = useCurrentUser();
    React.useEffect(() => {
        if (user.status === "idle") {
            user.refetch();
        }
    }, [client, user.status, user.refetch]);
    return null;
};
export const QoreProvider = (props) => {
    const userContextValue = React.useState(defaultUser);
    const contextValue = React.useMemo(() => ({ client: props.value }), [props.value]);
    return (_jsx(qoreHooks.context.Provider, Object.assign({ value: contextValue }, { children: _jsxs(UserContext.Provider, Object.assign({ value: userContextValue }, { children: [_jsx(UserFetcher, {}), props.children] })) })));
};
export const useCurrentUser = () => {
    const [user, setUser] = React.useContext(UserContext);
    const client = qoreHooks.useClient();
    const refetch = React.useCallback(() => __awaiter(void 0, void 0, void 0, function* () {
        setUser((user) => (Object.assign(Object.assign({}, user), { status: "loading" })));
        const nextState = yield client
            .currentUser()
            .then((user) => {
            if (typeof user !== "object") {
                return { status: "idle", error: null, user: null };
            }
            return {
                status: "success",
                user,
                error: null,
            };
        })
            .catch((error) => ({
            status: "error",
            user: null,
            error,
        }));
        setUser(nextState);
        return nextState;
    }), [client]);
    const nextUser = React.useMemo(() => (Object.assign(Object.assign({}, user), { refetch })), [user, refetch]);
    return nextUser;
};
const qore = Object.assign(Object.assign({}, qoreHooks), { QoreProvider,
    useCurrentUser });
export const useClient = qore.useClient;
export default qore;
//# sourceMappingURL=qore.js.map