import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "@emotion/react/jsx-runtime";
import React from "react";
import { Box, Button, Center, Flex, FormControl, FormLabel, Grid, GridItem, Icon, Input, InputGroup, InputLeftElement, Menu, MenuButton, MenuList, Portal, Select, SimpleGrid, Spacer, Stack, Tab, TabList, TabPanel, TabPanels, Tabs, Text, Tooltip, useDisclosure, } from "@chakra-ui/react";
import { Scrollbars } from "rc-scrollbars";
import { RuntimeContext } from "@qorebase/app-runtime/src/RuntimeContext";
import iconsList from "@qorebase/app-runtime/src/components/iconsList";
import StringPropertyEditor from "./property/string";
import { humanize } from "@qorebase/app-runtime/src/utils/humanizeString";
import { buildPage, } from "@qorebase/app-runtime/src/interfaces";
import PropertyEditorByType from "./property";
import { VariablesProvider } from "@qorebase/app-runtime/src/VariablesContext";
import { usePageVariables } from "./ComponentEditorPanel";
import { useSourceHooks } from "@qorebase/app-runtime/src/hooks/sourceHooks/useSourceHooks";
import { InfoOutlineIcon } from "@chakra-ui/icons";
import { ParamsEditorButton } from "./ParamsEditor";
export default function PageGeneral() {
    var _a, _b, _c, _d;
    const pageID = RuntimeContext.useSelectState((state) => state.control.page);
    const page = RuntimeContext.useSelectState((state) => state.app.maps.page[pageID]);
    const { variables: pageVariables } = usePageVariables();
    const tables = RuntimeContext.useSelectState((state) => state.app.schema.tables);
    const queries = RuntimeContext.useSelectState((state) => state.app.schema.queries);
    const tableWithViews = React.useMemo(() => tables
        .flatMap((table) => [table].concat(table.views || [], table.insights || []))
        .concat((page === null || page === void 0 ? void 0 : page.mode) !== "form" ? queries || [] : []), [tables, queries, page === null || page === void 0 ? void 0 : page.mode]);
    const view = React.useMemo(() => {
        return tables.find((view) => view.name === (page === null || page === void 0 ? void 0 : page.sourceID));
    }, [tables, page === null || page === void 0 ? void 0 : page.sourceID]);
    const runtimeActions = RuntimeContext.useActions();
    const iconDisclosure = useDisclosure();
    const [iconInputSearch, setIconInputSearch] = React.useState("");
    const handleRename = React.useCallback((title) => {
        runtimeActions.updatePage({ page: pageID }, (draft) => {
            draft.title = title;
        });
    }, [runtimeActions, pageID]);
    const handleTitleChange = React.useCallback((value) => {
        runtimeActions.setPageProperty({ page: pageID }, "title", value);
    }, [runtimeActions, pageID]);
    const handleRowIDChange = React.useCallback((defaultRowID) => {
        runtimeActions.updatePage({ page: pageID }, (draft) => {
            if (draft.defaultRow.type === "row-id") {
                draft.defaultRow.rowId = defaultRowID;
            }
        });
    }, [runtimeActions, pageID]);
    const source = React.useMemo(() => {
        return {
            rowId: null,
            type: "record",
            target: page === null || page === void 0 ? void 0 : page.sourceID,
            defaultRow: { type: "first-row" },
            params: {},
        };
    }, [page === null || page === void 0 ? void 0 : page.sourceID]);
    const sourceHooks = useSourceHooks(source);
    const handleUpdateParams = React.useCallback((slug, value) => {
        runtimeActions.updatePage({ page: pageID }, (draft) => {
            if (!draft.sourceParams) {
                draft.sourceParams = {};
            }
            draft.sourceParams[slug] = value;
        });
    }, [pageID]);
    const defaultPage = React.useMemo(() => buildPage(), []);
    if (!page)
        return null;
    return (_jsx(VariablesProvider, Object.assign({ variables: pageVariables }, { children: _jsx(Box, Object.assign({ as: "form", "data-test-id": "page-setting-panel", p: "4" }, { children: _jsxs(Stack, Object.assign({ spacing: 2 }, { children: [_jsxs(FormControl, { children: [_jsx(FormLabel, Object.assign({ fontWeight: "semibold" }, { children: "Name" })), _jsx(StringPropertyEditor, { onChange: handleRename, propDef: { type: "string", options: { format: "text" } }, propName: "name", value: page.title }, page.id)] }), _jsxs(FormControl, Object.assign({ pt: 2 }, { children: [_jsx(FormLabel, Object.assign({ fontWeight: "semibold" }, { children: "Title" })), _jsx(StringPropertyEditor, { propName: "title", value: page.properties.values["title"] ||
                                    defaultPage.properties.values["title"], view: view, propDef: { type: "string", options: { format: "text" } }, onChange: handleTitleChange }, "title")] })), _jsxs(FormControl, Object.assign({ pt: 2 }, { children: [_jsxs(FormLabel, Object.assign({ fontWeight: "semibold" }, { children: ["Data Source \u00A0", _jsx(Tooltip, Object.assign({ hasArrow: true, label: "In this page context you can choose the Qorebase table/grid which will be the source of data on this page." }, { children: _jsx(InfoOutlineIcon, {}) }))] })), _jsx(Select, Object.assign({ placeholder: "Default", size: "sm", value: page.sourceID, onChange: (e) => {
                                    const selected = e.currentTarget.value;
                                    runtimeActions.updatePage({ page: pageID }, (draft) => {
                                        draft.sourceID = selected;
                                    });
                                } }, { children: tableWithViews.map((view) => (_jsx("option", Object.assign({ value: view.name }, { children: view.name }), view.name))) }))] })), _jsxs(Flex, Object.assign({ pt: 2 }, { children: [_jsx(FormLabel, Object.assign({ flex: 0, fontWeight: "semibold" }, { children: "Prefetch" })), _jsx(PropertyEditorByType.boolean, { propDef: {
                                    type: "boolean",
                                    options: {},
                                }, propName: "limit", value: page.prefetch, onChange: (prefetch) => {
                                    runtimeActions.updatePage({ page: pageID }, (draft) => {
                                        draft.prefetch = prefetch;
                                    });
                                } })] })), sourceHooks.params.length > 0 && (_jsxs(_Fragment, { children: [_jsx(Text, Object.assign({ fontWeight: "semibold" }, { children: "Parameters" })), sourceHooks.params.map((param) => {
                                var _a;
                                return (_jsxs(Grid, Object.assign({ templateColumns: "repeat(12, 1fr)", gap: 2, my: "8px" }, { children: [_jsx(GridItem, Object.assign({ colSpan: 3, display: "flex", alignItems: "center" }, { children: _jsx(Text, { children: param.slug }) })), _jsx(GridItem, Object.assign({ colSpan: 9, my: "8px" }, { children: _jsx(PropertyEditorByType.string, { propDef: {
                                                    type: "string",
                                                    options: { format: "text" },
                                                }, propName: param.slug, value: (_a = page.sourceParams) === null || _a === void 0 ? void 0 : _a[param.slug], onChange: (val) => {
                                                    handleUpdateParams(param.slug, val);
                                                } }) }))] }), param.slug));
                            })] })), _jsxs(FormControl, Object.assign({ pt: 2 }, { children: [_jsxs(FormLabel, Object.assign({ fontWeight: "semibold" }, { children: ["Default Row Type \u00A0", _jsx(Tooltip, Object.assign({ hasArrow: true, label: "You can select data from a row in the table/grid in the page context. If you select first row it will display the first row of the table from the page context you choose." }, { children: _jsx(InfoOutlineIcon, {}) }))] })), _jsx(Select
                            // @ts-ignore
                            , Object.assign({ 
                                // @ts-ignore
                                value: ((_a = page === null || page === void 0 ? void 0 : page.defaultRow) === null || _a === void 0 ? void 0 : _a.type) || "first-row", size: "sm", onChange: (e) => {
                                    const type = e.currentTarget.value;
                                    runtimeActions.updatePage({ page: pageID }, (draft) => {
                                        draft.defaultRow =
                                            type === "row-id"
                                                ? { type, rowId: "" }
                                                : { type: "first-row" };
                                    });
                                } }, { children: ["row-id", "first-row"].map((mode) => (_jsx("option", Object.assign({ value: mode }, { children: humanize(mode) }), mode))) }))] })), ((_b = page === null || page === void 0 ? void 0 : page.defaultRow) === null || _b === void 0 ? void 0 : _b.type) === "row-id" && (_jsxs(FormControl, Object.assign({ pt: 2 }, { children: [_jsx(FormLabel, Object.assign({ fontWeight: "semibold" }, { children: "Default Row ID" })), _jsx(StringPropertyEditor, { onChange: handleRowIDChange, propDef: { type: "string", options: { format: "text" } }, propName: "defaultRowID", value: ((_c = page.defaultRow) === null || _c === void 0 ? void 0 : _c.type) === "row-id" && ((_d = page === null || page === void 0 ? void 0 : page.defaultRow) === null || _d === void 0 ? void 0 : _d.rowId) }, page.id)] }))), _jsx(ParamsEditorButton, { page: page }), _jsxs(FormControl, Object.assign({ pt: 2 }, { children: [_jsxs(FormLabel, Object.assign({ fontWeight: "semibold" }, { children: ["Page Mode \u00A0", _jsx(Tooltip, Object.assign({ hasArrow: true, label: "If you choose form mode, this page will send data to the table/grid that you have selected in the page context above." }, { children: _jsx(InfoOutlineIcon, {}) }))] })), _jsx(Select, Object.assign({ size: "sm", value: page.mode || "display", onChange: (e) => {
                                    const selected = e.currentTarget.value;
                                    runtimeActions.updatePage({ page: pageID }, (draft) => {
                                        // @ts-ignore
                                        draft.mode = selected;
                                    });
                                } }, { children: ["display", "form"].map((mode) => (_jsx("option", Object.assign({ value: mode }, { children: mode }), mode))) }))] })), page.mode === "form" && (_jsxs(FormControl, Object.assign({ pt: 2 }, { children: [_jsx(FormLabel, Object.assign({ fontWeight: "semibold" }, { children: "Form Actions" })), _jsx(PropertyEditorByType.action, { propDef: { type: "action", options: [{ type: "none" }] }, propName: "onSuccess", 
                                //  @ts-ignore
                                value: typeof page.properties.values["onSuccess"] === "undefined"
                                    ? defaultPage.properties.values["onSuccess"]
                                    : page.properties.values["onSuccess"], onChange: (value) => {
                                    runtimeActions.setPageProperty({ page: page.id }, "onSuccess", value);
                                } }), _jsxs(Flex, Object.assign({ pt: 4 }, { children: [_jsx(FormLabel, Object.assign({ flex: 0, fontWeight: "semibold" }, { children: "Show Delete" })), _jsx(PropertyEditorByType.boolean, { propDef: {
                                            type: "boolean",
                                            options: {},
                                        }, propName: "limit", value: page.properties.deletableForm, onChange: (deletableForm) => {
                                            runtimeActions.updatePage({ page: pageID }, (draft) => {
                                                draft.properties.deletableForm = deletableForm;
                                            });
                                        } })] }))] }))), _jsxs(FormControl, { children: [_jsxs(FormLabel, Object.assign({ fontWeight: "semibold" }, { children: ["Icon \u00A0", _jsx(Tooltip, Object.assign({ hasArrow: true, label: "This icon will appear when the page becomes menu (sidebar menu)." }, { children: _jsx(InfoOutlineIcon, {}) }))] })), _jsxs(Menu, Object.assign({ isOpen: iconDisclosure.isOpen, onClose: iconDisclosure.onClose }, { children: [_jsx(MenuButton, Object.assign({ as: Button, leftIcon: _jsx(Icon, { as: iconsList[page.icon] }), variant: "outline", fontWeight: "normal", textAlign: "left", w: "full", size: "sm", onClick: iconDisclosure.onOpen }, { children: humanize(page.icon || "Select icon") })), _jsx(Portal, { children: _jsx(MenuList, Object.assign({ p: "16px", width: "304px", height: "420px" }, { children: _jsxs(Tabs, Object.assign({ size: "sm" }, { children: [_jsxs(TabList, { children: [_jsx(Tab, Object.assign({ px: 0 }, { children: "All Icon" })), _jsx(Tab, Object.assign({ px: 0, ml: 4 }, { children: "Upload Icon" })), _jsx(Spacer, {}), _jsx(Button, Object.assign({ size: "sm", fontWeight: "normal", variant: "link", color: "black", _focus: { shadow: "none" }, _hover: { textDecoration: "none" }, display: !page.icon && "none", onClick: () => {
                                                                    runtimeActions.updatePage({ page: pageID }, (draft) => {
                                                                        // eslint-disable-next-line fp/no-delete -- immer
                                                                        delete draft.icon;
                                                                    });
                                                                    iconDisclosure.onClose();
                                                                } }, { children: "Remove" }))] }), _jsxs(TabPanels, { children: [_jsxs(TabPanel, Object.assign({ px: 0 }, { children: [_jsxs(InputGroup, { children: [_jsx(InputLeftElement, Object.assign({ pointerEvents: "none" }, { children: _jsx(Icon, { as: iconsList["Search"] }) })), _jsx(Input, { type: "text", placeholder: "Search icon", _placeholder: { fontSize: "sm" }, onChange: (e) => {
                                                                                    setIconInputSearch(e.target.value);
                                                                                } })] }), _jsx(Box, Object.assign({ py: 4, overflowY: "auto", height: "308px" }, { children: _jsx(Scrollbars, { children: _jsx(SimpleGrid, Object.assign({ columns: 7, spacing: "10px" }, { children: Object.keys(iconsList)
                                                                                    .filter((icon) => icon
                                                                                    .toLowerCase()
                                                                                    .includes(iconInputSearch.trim()))
                                                                                    .map((icon) => {
                                                                                    return (_jsx(Box, Object.assign({ height: "30px", cursor: "pointer", onClick: () => {
                                                                                            runtimeActions.updatePage({ page: pageID }, (draft) => {
                                                                                                draft.icon = icon;
                                                                                            });
                                                                                            iconDisclosure.onClose();
                                                                                        } }, { children: _jsx(Center, Object.assign({ borderRadius: "md", _hover: { backgroundColor: "#F6F6F6" }, h: "30px", w: "30px" }, { children: _jsx(Icon, { fontSize: "lg", as: iconsList[icon] }) })) }), icon));
                                                                                }) })) }) }))] })), _jsx(TabPanel, Object.assign({ px: 0 }, { children: _jsx(Box, Object.assign({ height: "308px", display: "flex", alignItems: "center", justifyContent: "center" }, { children: _jsx(Text, { children: "Coming Soon" }) })) }))] })] })) })) })] }))] })] })) })) })));
}
//# sourceMappingURL=PageGeneral.js.map