import { __awaiter } from "tslib";
import React from "react";
import { initialApp, RuntimeContext, } from "@qorebase/app-runtime/src/RuntimeContext";
import { useForm } from "react-hook-form";
import qoreStorageClient from "../hooks/qoreStorageClient";
import { useRouter } from "next/router";
import EditorContext from "@qorebase/app-runtime/src/EditorContext";
import { DefaultApiFactory } from "@qorebase/sdk";
import useSWRImmutable from "swr/immutable";
import { importLocalNpmComponent, importNpmComponent, listLocalComponents, } from "@qorebase/app-runtime/src/utils/importComponent";
import { getBuiltinImporters } from "@qorebase/app-runtime/src/builtinComponents";
export default React.memo(function TitleBar() {
    var _a;
    const router = useRouter();
    const form = useForm({ mode: "onBlur", defaultValues: { title: "" } });
    const runtimeActions = RuntimeContext.useActions();
    const runtimeHistory = RuntimeContext.useHistory();
    const control = RuntimeContext.useSelectState((state) => state.control);
    const page = RuntimeContext.useSelectState((state) => state.app.maps.page[control.page]);
    const applications = qoreStorageClient.view("application-detail").useListRow({
        params: {
            appId: router.query.appID,
            projectId: router.query.projectID,
        },
        populate: ["project"],
        limit: 1,
    });
    const currentApp = React.useMemo(() => applications.data[0], [applications.data]);
    const { data: releases } = qoreStorageClient.table("release_log").useListRow({
        condition: {
            release: {
                project: (_a = currentApp === null || currentApp === void 0 ? void 0 : currentApp.project) === null || _a === void 0 ? void 0 : _a.id,
            },
            stage: "staging",
        },
        orderBy: {
            updated_at: "DESC",
        },
        limit: 1,
    }, {
        skip: !currentApp,
    });
    const qoreDataEndpoint = React.useMemo(() => {
        var _a, _b;
        const endpoint = (_b = (_a = releases === null || releases === void 0 ? void 0 : releases[0]) === null || _a === void 0 ? void 0 : _a.user_overrides) === null || _b === void 0 ? void 0 : _b["qore-data"].domains.split(",")[0];
        return endpoint && `https://${endpoint}`;
    }, [releases]);
    const adminSecret = React.useMemo(() => { var _a, _b; return (_b = (_a = releases === null || releases === void 0 ? void 0 : releases[0]) === null || _a === void 0 ? void 0 : _a.user_overrides) === null || _b === void 0 ? void 0 : _b["qore-data"].admin_secret; }, [releases]);
    const qoreDataApi = DefaultApiFactory({
        apiKey: adminSecret,
        isJsonMime: (mime) => {
            const jsonMime = new RegExp("^(application/json|[^;/ \\t]+/[^;/ \\t]+[+]json)[ \\t]*(;.*)?$", "i");
            return (mime !== null &&
                (jsonMime.test(mime) ||
                    mime.toLowerCase() === "application/json-patch+json"));
        },
    }, qoreDataEndpoint);
    const { data: schema } = useSWRImmutable([qoreDataEndpoint, "schema"], () => __awaiter(this, void 0, void 0, function* () {
        const { data } = yield qoreDataApi.getSchema();
        return {
            tables: data.tables.map((table) => (Object.assign(Object.assign({}, table), { columns: table.columns.map((column) => {
                    var _a, _b;
                    // delete action source code from schema
                    return column.type === "action" &&
                        ((_a = column.definition) === null || _a === void 0 ? void 0 : _a.action) === "JavaScript"
                        ? Object.assign(Object.assign({}, column), { definition: Object.assign(Object.assign({}, column.definition), { function: "" }) })
                        : column.type === "action" &&
                            ((_b = column.definition) === null || _b === void 0 ? void 0 : _b.action) === "Print"
                            ? Object.assign(Object.assign({}, column), { definition: Object.assign(Object.assign({}, column.definition), { template: "" }) })
                            : column;
                }) }))),
            queries: data.queries || [],
        };
    }), {
        isPaused: () => !(qoreDataEndpoint && adminSecret),
    });
    React.useEffect(() => {
        if (!page)
            return;
        form.reset({ title: page.title });
    }, [page === null || page === void 0 ? void 0 : page.title]);
    const loaded = EditorContext.useSelectState((state) => state.loaded);
    const editorActions = EditorContext.useActions();
    const revisionID = EditorContext.useSelectState((state) => state.revisionID);
    React.useEffect(() => {
        if (!revisionID || !schema || loaded || !qoreDataEndpoint || !adminSecret)
            return;
        (() => __awaiter(this, void 0, void 0, function* () {
            var _a, _b, _c, _d, _e;
            const revisionResult = yield qoreStorageClient.client
                .table("revisions")
                .readRows({
                condition: {
                    id: { $eq: revisionID },
                },
                limit: 1,
            })
                .toPromise();
            const revision = (_a = revisionResult.data) === null || _a === void 0 ? void 0 : _a.nodes[0];
            const appResult = yield qoreStorageClient.client
                .table("applications")
                .readRows({
                condition: {
                    id: { $eq: revision === null || revision === void 0 ? void 0 : revision.apprevision },
                },
            }, { skip: !(revision === null || revision === void 0 ? void 0 : revision.apprevision) })
                .toPromise();
            const app = (_b = appResult.data) === null || _b === void 0 ? void 0 : _b.nodes[0];
            if (!revision || !app)
                return;
            const application = Object.assign(Object.assign(Object.assign({}, initialApp.components), revision.data), { name: app.name, description: app.description, icon: ((_c = app.icon) === null || _c === void 0 ? void 0 : _c.url) || "" });
            try {
                const cfg = Object.assign(Object.assign({}, application.config), { projectID: router.query.projectID, appID: router.query.appID });
                const config = Object.assign(Object.assign({}, cfg), { endpoint: qoreDataEndpoint });
                application.config = config;
                application.schema = Object.assign(Object.assign({}, schema), { views: schema.tables.flatMap((table) => (table.views || []).map((view) => {
                        var _a;
                        return ({
                            name: view.name,
                            query: view.query,
                            columns: (((_a = view.query) === null || _a === void 0 ? void 0 : _a.fields) || [])
                                .map((columnName) => table.columns.find((column) => column.name === columnName))
                                .filter(Boolean),
                            sorts: view.sorts,
                        });
                    })), insights: schema.tables.flatMap((table) => (table.insights || []).map((insight) => ({
                        name: insight.name,
                        columns: insight.columns,
                        table: table.name,
                        sorts: insight.sorts,
                        insight: insight.insight,
                        params: insight.params,
                        registeredParams: insight.registeredParams,
                    }))), 
                    // @ts-ignore
                    queries: schema.queries });
                editorActions.setQoreDataConfig({
                    endpoint: qoreDataEndpoint,
                    adminSecret: adminSecret,
                });
                const usedComponents = [
                    ...new Set(Object.values(application.maps.component).map((c) => c.componentID)),
                ];
                const npmComponents = application.components.filter((component) => component.enabled);
                const { importUsedBuiltinComponents, importUnusedBuiltinComponents } = getBuiltinImporters(usedComponents, npmComponents.map((c) => c.name));
                yield Promise.all([
                    ...npmComponents.map((component) => importNpmComponent(component.name, component.version)),
                    ...listLocalComponents().map(importLocalNpmComponent),
                    importUsedBuiltinComponents(),
                ]);
                importUnusedBuiltinComponents();
                editorActions.setSchema(application.schema);
            }
            catch (error) {
                console.error("error", error);
            }
            application.theme = Object.assign({ id: "Light", options: { primaryColor: "#0064ff" }, navigationLayout: "sidebar" }, application.theme);
            if (((_d = application.maps.component.register_role_input) === null || _d === void 0 ? void 0 : _d.properties.roleId) === "") {
                const { data } = yield qoreDataApi.getAllRolesAndPermissions();
                const defaultRole = ((_e = data.roles.filter((role) => !["admin", "public"].includes(role.name))[0]) === null || _e === void 0 ? void 0 : _e.id) || "";
                // @ts-ignore
                application.maps.component.register_role_input.properties.roleId =
                    defaultRole;
            }
            runtimeActions.setApp(application);
            runtimeHistory.clear();
            console.log("app revision loaded", revisionID, revision.id);
        }))();
    }, [revisionID, router.query, loaded, schema, editorActions]);
    return null;
});
//# sourceMappingURL=TitleBar.js.map