import { nodeResolve } from "@rollup/plugin-node-resolve";
import typescript from "@rollup/plugin-typescript";
import commonjs from "@rollup/plugin-commonjs";
import { createRequire } from "module";
import path from "node:path";
const require = createRequire(import.meta.url);
const packageJson = require("./package.json");

const getDependencies = (name, dependencies = []) => {
  const depPackageJson = require(`${name}/package.json`);
  const newDependencies = depPackageJson
    ? [
        ...Object.keys(depPackageJson.dependencies || {}),
        ...Object.keys(depPackageJson.peerDependencies || {}),
      ]
    : [];
  return [name, ...newDependencies].reduce(
    (deps, name) =>
      deps.includes(name) ? deps : getDependencies(name, [...deps, name]),
    dependencies
  );
};

// package to force external
const externalPaths = [
  "react",
  "react-dom",
  "@qorebase/app-component",
  "@emotion/react",
  "lodash",
];

// bundle package ignoring its dependencies
const bundlePath = [
  "@qorebase/qore-apps",
  "@qorebase/app-runtime",
  path.resolve("/packages/runtime"),
];

// bundle package with its dependencies
const bundlePackage = [];

const paths = bundlePackage
  .reduce((paths, name) => getDependencies(name, paths), bundlePath)
  .filter((path) => !externalPaths.includes(path));

const filename = packageJson.module.slice(
  "lib/".length,
  packageJson.module.indexOf(".")
);

/**
 * @type {import('rollup').RollupOptions}
 */
const rollupOptions = {
  input: `src/${filename}.tsx`,
  output: {
    file: `lib/${filename}.js`,
    format: "esm",
  },
  treeshake: {
    moduleSideEffects: false,
  },
  external: (id) => {
    return (
      !paths.some(
        (pkg) =>
          id.startsWith(`${pkg}/`) ||
          id === pkg ||
          id.includes(`node_modules/${pkg}/`)
      ) &&
      (id.includes("node_modules/") ||
        !(id.startsWith("/") || id.startsWith(".") || id.startsWith("src")))
    );
  },
  plugins: [
    commonjs(),
    nodeResolve({
      browser: true,
    }),
    typescript(),
  ],
};

export default rollupOptions;
